﻿import {Page, NavController} from 'ionic/ionic';

import {CategoryPage} from './category/category';
import {TicketView} from './ticket/ticket';
import {VotingView} from './voting/voting';
import {CollectView} from './collect/collect';
import {ForbesView} from './forbes/forbes';

import {HttpService} from '../../units/http';
import {ConsoleService} from '../../units/console';


@Page({
    templateUrl: 'app/02.event/event.html'
})
export class EventPage {
    constructor(nav: NavController, http: HttpService, console: ConsoleService) {

        this.nav = nav;
        this.http = http;
        this.console = console;

        // 初始化配置
        // ---------------------------------
        this.reveal = true;
        this.topEventData = {
            'uid': JSON.parse(localStorage.getItem('user')).uid,
            'token': JSON.parse(localStorage.getItem('user')).token
        }

        // 热门活动：抢票 & ...
        // ---------------------------------
        this.http.server(JSON.parse(localStorage.getItem('todo')).event.topTicket,this.topEventData).subscribe(
            topTicketResponse => {
                this.console.log('热门抢票',[]); //JSON.stringify(topTicketResponse.dataRows)
                this.topTicket = topTicketResponse.dataRows;
            }    
        );


        // 正在进行： 抢票 & ...
        // ---------------------------------
        let doingTicketData = {
            'uid': JSON.parse(localStorage.getItem('user')).uid,
            'token': JSON.parse(localStorage.getItem('user')).token,

            'curPage' : JSON.parse(localStorage.getItem('post')).event.index,
            'pageSize': JSON.parse(localStorage.getItem('post')).event.display,
            'orderBy': JSON.parse(localStorage.getItem('post')).event.orderBy,
            'order': JSON.parse(localStorage.getItem('post')).event.order,
            'state': JSON.parse(localStorage.getItem('post')).event.doingState
        }
        this.http.server(JSON.parse(localStorage.getItem('todo')).event.ticket,doingTicketData).subscribe(
            doingTicketResponse => {
                this.console.log('正在进行[抢票]',[]); //JSON.stringify(topTicketResponse.dataRows)
                this.doingTicket = doingTicketResponse.dataRows;
            }    
        );
    }


    // 活动分类：抢票、投票、报名、排行
    // ---------------------------------
    allTicket(){
        this.nav.push(CategoryPage,{
            category: 'ticket',
            todo: JSON.parse(localStorage.getItem('todo')).event.ticket,
            view: 'TicketView'
        });
    }

    allVoting(){
        this.nav.push(CategoryPage,{
            category: 'voting',
            todo: JSON.parse(localStorage.getItem('todo')).event.voting,
            view: 'VotingView'
        });
    }

    allCollect(){
        this.nav.push(CategoryPage,{
            category: 'collect',
            todo: JSON.parse(localStorage.getItem('todo')).event.collect,
            view: 'CollectView'
        });
    }

    allForbes(){
        this.nav.push(CategoryPage,{
            category: 'forbes',
            todo: JSON.parse(localStorage.getItem('todo')).event.forbes,
            view: 'ForbesView'
        });
    }

    // 热门推荐：抢票 & ...
    // ---------------------------------
    viewTicket(ticket){
        this.nav.push(TicketView,{
            ticket: ticket
        });
    }



    doRefresh(refresher) {
        console.log('Refreshing!', refresher);
       
        setTimeout(() => {
            console.log('Pull to refresh complete!', refresher);
            refresher.complete();
        })
    }
    
    doStarting() {
        console.log('Pull started!');
    }
    
    doPulling(amt) {
        console.log('You have pulled', amt);
    }

}
