﻿import {Page, Config, NavParams, NavController} from 'ionic/ionic';
import {Validators, Control, ControlGroup} from 'angular2/angular2';

import {HttpService} from '../../../units/http';
import {ConsoleService} from '../../../units/console';


@Page({
    templateUrl: 'app/03.news/view/view.html'
})
export class NewsView {
    constructor(nav: NavController, params: NavParams, http: HttpService, console: ConsoleService) {

        this.nav = nav;

        this.http = http;
        this.console = console;

        this.form = new ControlGroup({
            comment: new Control('',Validators.required)
        });

        this.prompt = '暂无提示';
        this.promptOpacity = 0.6;
        this.promptStyle = {
            'min-height':'0rem',
            'display':'none',
            'opacity': this.promptOpacity
        }


        // 初始化配置
        // ---------------------------------
        this.reveal = false;
        this.news = params.get('news');
        this.content = this.news.content;
        this.isLike = this.news.isPraised;
        
        this.newIndex = JSON.parse(localStorage.getItem('post')).newReply.index;
        this.newDisplay = JSON.parse(localStorage.getItem('post')).newReply.display;

        this.topIndex = JSON.parse(localStorage.getItem('post')).topReply.index;
        this.topDisplay = JSON.parse(localStorage.getItem('post')).topReply.display;

        this.newReplyData = {
            'uid': JSON.parse(localStorage.getItem('user')).uid,
            'token': JSON.parse(localStorage.getItem('user')).token,
            "informationId": this.news.id,
            "curPage": this.newIndex,
            "pageSize": this.newDisplay
        }

        //this.topReplyData = {
        //    'uid': JSON.parse(localStorage.getItem('user')).uid,
        //    'token': JSON.parse(localStorage.getItem('user')).token,
        //    "informationId": this.news.id,
        //    "curPage": this.topIndex,
        //    "pageSize": this.topDisplay
        //}

        this.http.server(JSON.parse(localStorage.getItem('todo')).news.newReply, this.newReplyData).subscribe(
            newReplyResponse => {
                this.console.log('最新评论',[JSON.stringify(newReplyResponse.dataRows)]);
                this.newReply = newReplyResponse.dataRows;
            },
            error => {
                // TODO-错误页面
            }
        );

        //this.http.server(JSON.parse(localStorage.getItem('todo')).news.topReply, this.topReplyData).subscribe(
        //    topReplyResponse => {
        //        this.console.log('热门评论',[JSON.stringify(topReplyResponse.dataRows)]);
        //        this.topReply = topReplyResponse.dataRows;
        //    },
        //    error => {
        //        // TODO-错误页面
        //    }
        //);

    }


    // 喜欢 & 取消
    // ---------------------------------
    like(){
        this.isLike = !this.isLike;
        
        localStorage.setItem('NewsRefresh','ture');
    }

    // 发表评论
    // ---------------------------------
    reply(event){
        if(this.form.value.comment.length >= 6){
            let replyNewsData = {
                'uid': JSON.parse(localStorage.getItem('user')).uid,
                'token': JSON.parse(localStorage.getItem('user')).token,
                'content': this.form.value.comment,
                'informationId': this.news.id,
                'pid': '0',
            }
            this.http.server(JSON.parse(localStorage.getItem('todo')).news.reply, replyNewsData).subscribe(
                replyNewsResponse => {
                    this.console.log('发表评论',[JSON.stringify(replyNewsResponse)]);
                    if(replyNewsResponse.flag && replyNewsResponse.isSuccess){
                        document.getElementById('comment').value = '';
                        this.http.server(JSON.parse(localStorage.getItem('todo')).news.newReply, this.newReplyData).subscribe(
                            newReplyResponse => {
                                this.console.log('刷新评论',[JSON.stringify(newReplyResponse.dataRows)]);
                                this.newReply = newReplyResponse.dataRows;
                            },
                            error => {
                                // TODO-错误页面
                            }
                        );
                        this.prompt = '发表评论成功！';
                        this.promptStyle = {
                            'min-height':'0rem',
                            'display':'block',
                            'opacity': this.promptOpacity
                        }
                        setTimeout(() => {
                            let  timer = setInterval(() => {
                                if(this.promptOpacity <= 0){
                                    clearInterval(timer);
                                    this.promptOpacity = 0.6;
                                    this.promptStyle = {
                                        'min-height':'0rem',
                                        'display':'none',
                                        'opacity': this.promptOpacity
                                    }
                                }else{
                                    this.promptStyle = {
                                        'min-height':'0rem',
                                        'display':'block',
                                        'opacity': this.promptOpacity
                                    }
                                    this.promptOpacity = this.promptOpacity - 0.02;
                                }
                            },50);
                        },5000);
                    }
                },
                error => {
                    // TODO-错误页面
                    this.prompt = '评论失败，请稍后再试！';
                    this.promptStyle = {
                        'min-height':'0rem',
                        'display':'block',
                        'opacity': this.promptOpacity
                    }
                    setTimeout(() => {
                        let  timer = setInterval(() => {
                            if(this.promptOpacity <= 0){
                                clearInterval(timer);
                                this.promptOpacity = 0.6;
                                this.promptStyle = {
                                    'min-height':'0rem',
                                    'display':'none',
                                    'opacity': this.promptOpacity
                                }
                            }else{
                                this.promptStyle = {
                                    'min-height':'0rem',
                                    'display':'block',
                                    'opacity': this.promptOpacity
                                }
                                this.promptOpacity = this.promptOpacity - 0.02;
                            }
                        },50);
                    },5000);
                }
            );
        }else{
            this.prompt = '评论内容不得少于6个字！';
            this.promptStyle = {
                'min-height':'0rem',
                'display':'block',
                'opacity': this.promptOpacity
            }
            setTimeout(() => {
                let  timer = setInterval(() => {
                    if(this.promptOpacity <= 0){
                        clearInterval(timer);
                        this.promptOpacity = 0.6;
                        this.promptStyle = {
                            'min-height':'0rem',
                            'display':'none',
                            'opacity': this.promptOpacity
                        }
                    }else{
                        this.promptStyle = {
                            'min-height':'0rem',
                            'display':'block',
                            'opacity': this.promptOpacity
                        }
                        this.promptOpacity = this.promptOpacity - 0.02;
                    }
                },50);
            },5000);
        }
        event.preventDefault();
        
        localStorage.setItem('NewsRefresh','ture');
    }

    // 分享 & 转发
    // ---------------------------------


    // 页面生命周期
    // ---------------------------------
    //onPageLoaded(){
    //    this.console.log('NewsView',['onPageLoaded','页面加载完成！']);
    //}

    //onPageWillEnter(){
    //    this.console.log('NewsView',['onPageWillEnter','页面即将激活！']);
    //}

    onPageDidEnter(){
        let viewNewsData = {
            'uid': JSON.parse(localStorage.getItem('user')).uid,
            'token': JSON.parse(localStorage.getItem('user')).token,
            "informationId": this.news.id
        }
        this.http.server(JSON.parse(localStorage.getItem('todo')).news.view, viewNewsData).subscribe(
            viewNewsResponse => {
                this.console.log('资讯详情',[JSON.stringify(viewNewsResponse)]);
            },
            error => {
                // TODO-错误页面
            }
        );
        this.console.log('NewsView',['onPageDidEnter','页面已经激活！']);
    }

    onPageWillLeave (){
        if(this.isLike != this.news.isPraised){
            let likeNewsData = {
                'uid': JSON.parse(localStorage.getItem('user')).uid,
                'token': JSON.parse(localStorage.getItem('user')).token,
                "informationId": this.news.id
            }
            this.http.server(JSON.parse(localStorage.getItem('todo')).news.like, likeNewsData).subscribe(
                likeNewsResponse => {
                    this.console.log('资讯点赞',[JSON.stringify(likeNewsResponse)]);
                },
                error => {
                    // TODO-错误页面
                }
            );
        }
        this.console.log('NewsView',['onPageWillLeave','页面即将退出！']);
    }

    //onPageDidLeave() {
    //    this.console.log('NewsView',['onPageDidLeave','页面已经退出！']);
    //}

    //onPageWillUnload (){
    //    this.console.log('NewsView',['onPageWillUnload','页面即将销毁！']);
    //}

    //onPageDidUnload (){
    //    this.console.log('NewsView',['onPageDidUnload','页面已经销毁！']);
    //}
}
