﻿import {Page, NavParams, NavController, Popup} from 'ionic/ionic';
import {FormBuilder,Control, Validators, ControlGroup} from 'angular2/angular2';

import {HttpService} from '../../../units/http';
import {ConsoleService} from '../../../units/console';


@Page({
    templateUrl: 'app/04.talk/view/view.html'
})
export class TalkView {
    constructor(nav: NavController, params: NavParams,popup: Popup, http: HttpService, console: ConsoleService) {
        this.nav = nav;

        this.http = http;
        this.console = console;

        this.popup = popup;

        this.prompt = '暂无提示';
        this.promptOpacity = 0.6;
        this.promptStyle = {
            'min-height':'0rem',
            'display':'none',
            'opacity': this.promptOpacity
        }

        // 初始化参数
        // ---------------------------------  
        this.talk = params.get('talk');
        this.isLike = this.talk.isPraised;

        this.form = new ControlGroup({
            comment: new Control('', Validators.required)
        });

        // TODO-缓存读取：热门评论、最新评论
        // ---------------------------------  
        this.index = JSON.parse(localStorage.getItem('post')).newReply.index;
        this.newReplyData = {
            'uid': JSON.parse(localStorage.getItem('user')).uid,
            'token': JSON.parse(localStorage.getItem('user')).token,
            'circleId': this.talk.id,
            'orderBy': JSON.parse(localStorage.getItem('post')).newReply.orderBy,
            'order': JSON.parse(localStorage.getItem('post')).newReply.order,
            'curPage': '1',
            'pageSize': '20'
        }
        this.http.server(JSON.parse(localStorage.getItem('todo')).talk.newReply, this.newReplyData).subscribe(
            newReplyResponse => {
                this.newReply = newReplyResponse.dataRows;
                this.console.log('最新评论：',[JSON.stringify(newReplyResponse.dataRows)]); // JSON.stringify(newReplyResponse.dataRows)
            }
        );
    }


    // 评论详情
    // ---------------------------------  
    viewReview(review){
        this.nav.push(ReviewPage,{
            category: 'post',
            quote: this.quote,
            review: review
        });
    }


    // 喜欢 & 取消
    // ---------------------------------
    like(){
        this.isLike = !this.isLike;
        
        localStorage.setItem('TalkRefresh','ture');
    }
    

    // 发表评论
    // ---------------------------------
    reply(event){
        if(this.form.value.comment.length >= 6){
            let replyTalkData = {
                'uid': JSON.parse(localStorage.getItem('user')).uid,
                'token': JSON.parse(localStorage.getItem('user')).token,
                'content': this.form.value.comment,
                'circleId': this.talk.id,
                'mediaType':'1',
                'media': ''
            }
            this.http.server(JSON.parse(localStorage.getItem('todo')).talk.reply, replyTalkData).subscribe(
                replyTalkResponse => {
                    this.console.log('发表评论',[JSON.stringify(replyTalkResponse)]);
                    if(replyTalkResponse.flag && replyTalkResponse.isSuccess){
                        document.getElementById('comment').value = '';
                        this.http.server(JSON.parse(localStorage.getItem('todo')).talk.newReply, this.newReplyData).subscribe(
                            newReplyResponse => {
                                this.console.log('刷新评论',[JSON.stringify(newReplyResponse.dataRows)]);
                                this.newReply = newReplyResponse.dataRows;
                            },
                            error => {
                                // TODO-错误页面
                            }
                        );
                        this.prompt = '发表评论成功！';
                        this.promptStyle = {
                            'min-height':'0rem',
                            'display':'block',
                            'opacity': this.promptOpacity
                        }
                        setTimeout(() => {
                            let  timer = setInterval(() => {
                                if(this.promptOpacity <= 0){
                                    clearInterval(timer);
                                    this.promptOpacity = 0.6;
                                    this.promptStyle = {
                                        'min-height':'0rem',
                                        'display':'none',
                                        'opacity': this.promptOpacity
                                    }
                                }else{
                                    this.promptStyle = {
                                        'min-height':'0rem',
                                        'display':'block',
                                        'opacity': this.promptOpacity
                                    }
                                    this.promptOpacity = this.promptOpacity - 0.02;
                                }
                            },50);
                        },5000);
                    }
                },
                error => {
                    // TODO-错误页面
                    this.prompt = '评论失败，请稍后再试！';
                    this.promptStyle = {
                        'min-height':'0rem',
                        'display':'block',
                        'opacity': this.promptOpacity
                    }
                    setTimeout(() => {
                        let  timer = setInterval(() => {
                            if(this.promptOpacity <= 0){
                                clearInterval(timer);
                                this.promptOpacity = 0.6;
                                this.promptStyle = {
                                    'min-height':'0rem',
                                    'display':'none',
                                    'opacity': this.promptOpacity
                                }
                            }else{
                                this.promptStyle = {
                                    'min-height':'0rem',
                                    'display':'block',
                                    'opacity': this.promptOpacity
                                }
                                this.promptOpacity = this.promptOpacity - 0.02;
                            }
                        },50);
                    },5000);
                }
            );
        }else{
            this.prompt = '评论内容不得少于6个字！';
            this.promptStyle = {
                'min-height':'0rem',
                'display':'block',
                'opacity': this.promptOpacity
            }
            setTimeout(() => {
                let  timer = setInterval(() => {
                    if(this.promptOpacity <= 0){
                        clearInterval(timer);
                        this.promptOpacity = 0.6;
                        this.promptStyle = {
                            'min-height':'0rem',
                            'display':'none',
                            'opacity': this.promptOpacity
                        }
                    }else{
                        this.promptStyle = {
                            'min-height':'0rem',
                            'display':'block',
                            'opacity': this.promptOpacity
                        }
                        this.promptOpacity = this.promptOpacity - 0.02;
                    }
                },50);
            },5000);
        }
        event.preventDefault();
        
        localStorage.setItem('TalkRefresh','ture');
    }


    // 页面生命周期
    // ---------------------------------
    //onPageLoaded(){
    //    this.console.log('TalkView',['onPageLoaded','页面加载完成！']);
    //}

    //onPageWillEnter(){
    //    this.console.log('TalkView',['onPageWillEnter','页面即将激活！']);
    //}

    //onPageDidEnter(){
    //    this.console.log('TalkView',['onPageDidEnter','页面已经激活！']);
    //}

    onPageWillLeave (){
        if(this.isLike != this.talk.isPraised){
            let likeTalkData = {
                'uid': JSON.parse(localStorage.getItem('user')).uid,
                'token': JSON.parse(localStorage.getItem('user')).token,
                "circleId": this.talk.id
            }
            this.http.server(JSON.parse(localStorage.getItem('todo')).talk.like, likeTalkData).subscribe(
                likeTalkResponse => {
                    this.console.log('话题点赞',[JSON.stringify(likeTalkResponse)]);
                },
                error => {
                    // TODO-错误页面
                }
            );
        }
        this.console.log('TalkView',['onPageWillLeave','页面即将退出！']);
    }

    //onPageDidLeave() {
    //    this.console.log('TalkView',['onPageDidLeave','页面已经退出！']);
    //}

    //onPageWillUnload (){
    //    this.console.log('TalkView',['onPageWillUnload','页面即将销毁！']);
    //}

    //onPageDidUnload (){
    //    this.console.log('TalkView',['onPageDidUnload','页面已经销毁！']);
    //}
}
