﻿import {Page, Popup, NavController} from 'ionic/ionic';

import {StarForbes} from './starForbes/starForbes';
import {UserForbes} from './userForbes/userForbes';
import {UserProfile} from '../../base/user/profile/profile';

import {HttpService} from '../../units/http';
import {ConsoleService} from '../../units/console';


@Page({
    templateUrl: 'app/06.lover/lover.html'
})
export class LoverPage {
    constructor(nav: NavController, popup: Popup, http: HttpService, console: ConsoleService) {

        this.nav = nav;
        this.popup = popup;
        this.http = http;
        this.console = console;

        
        // 初始化参数
        // ---------------------------------
        this.addedStarData = {
            'uid': JSON.parse(localStorage.getItem('user')).uid,
            'token': JSON.parse(localStorage.getItem('user')).token,
            'curPage': '1',
            'pageSize': '20',
            'orderBy': 'id',
            'order':'desc'
        }
        this.http.server(JSON.parse(localStorage.getItem('todo')).star.added, this.addedStarData).subscribe(
            addedStarResponse => {
                this.stars = addedStarResponse.dataRows;
                this.rowStyle = {
                    'width': (this.stars.length * 68) + 'px'
                }
                this.index = this.stars[0];
                this.indexName = this.index.starName;
                this.indexDistance = this.index.distance > 0 ? this.index.distance : 0;
                //this.indexDistance = this.index.distance > 0 ? this.index.initialDistance - this.index.distance : this.index.initialDistance;
                this.latestDistance = parseInt((this.indexDistance/this.index.initialDistance)*100 );
                this.console.log('百分比：',[this.latestDistance,this.index.initialDistance]);
                //this.loader(this.index.initialDistance, this.index.distance > 0 ? this.index.distance : this.index.indexDistance);
                this.console.log('已关注明星：',[JSON.stringify(addedStarResponse.dataRows)]); // JSON.stringify(newReplyResponse.dataRows)
            }
        );

        this.userInfoData = {
            'uid': JSON.parse(localStorage.getItem('user')).uid,
            'token': JSON.parse(localStorage.getItem('user')).token
        }

        this.http.server(JSON.parse(localStorage.getItem('todo')).user.info, this.userInfoData).subscribe(
            userInfoResponse => {
                //this.user = userInfoResponse.dataRows;
                this.console.log('个人信息：',[JSON.stringify(userInfoResponse)]); // JSON.stringify(newReplyResponse.dataRows)

                this.avatar = userInfoResponse.headPic;
                this.nickName = userInfoResponse.nickName;
                this.level = userInfoResponse.gamelevel;
                this.integral = userInfoResponse.integral;


            }
        );

    }

    // 个人信息
    // ---------------------------------
    userProfile(){
        this.nav.push(UserProfile);
    }

    // 明星排行榜
    // ---------------------------------
    starForbes(){
        this.nav.push(StarForbes);
    }


    // 用户排行榜
    // ---------------------------------
    userForbes(){
        this.nav.push(UserForbes);
    }


    // 取消关注
    // ---------------------------------
    unlike(){
        let delStarData = {
            'uid': JSON.parse(localStorage.getItem('user')).uid,
            'token': JSON.parse(localStorage.getItem('user')).token,
            'starId': this.index.starId
        }
        this.http.server(JSON.parse(localStorage.getItem('todo')).star.del, delStarData).subscribe(
            delStarResponse => {
                this.console.log('取消关注：',[JSON.stringify(delStarResponse)]); // JSON.stringify(newReplyResponse.dataRows)
                this.http.server(JSON.parse(localStorage.getItem('todo')).star.added, this.addedStarData).subscribe(
                    addedStarResponse => {
                        this.stars = addedStarResponse.dataRows;
                        this.rowStyle = {
                            'width': (this.stars.length * 68) + 'px'
                        }
                        this.index = this.stars[0];
                        this.indexName = this.index.starName;
                        this.indexDistance = this.index.distance > 0 ? this.index.distance : 0;
                        this.loader(this.index.initialDistance, this.index.distance > 0 ? this.index.distance : this.index.indexDistance);
                        this.console.log('已关注明星：',[JSON.stringify(addedStarResponse.dataRows)]); // JSON.stringify(newReplyResponse.dataRows)
                    }
                );
            }
        );
    }

    // 切换明星
    // ---------------------------------
    details(star){
        this.index = star;
        this.indexName = this.index.starName;
        this.indexDistance = this.index.distance > 0 ? this.index.distance : 0;
        this.latestDistance = parseInt((this.indexDistance/this.index.initialDistance)*100 );
        this.console.log('百分比：',[this.latestDistance,this.index.initialDistance]);
        //this.loader(this.index.initialDistance, this.index.distance > 0 ? this.index.distance : this.index.indexDistance);
    }


    // 邀请码
    // ---------------------------------
    invite(){
        let userKeyData = {
            'uid': JSON.parse(localStorage.getItem('user')).uid,
            'token': JSON.parse(localStorage.getItem('user')).token
        }
        this.http.server(JSON.parse(localStorage.getItem('todo')).user.key, userKeyData).subscribe(
           userKeyResponse => {
               if(userKeyResponse.flag){
                   this.popup.alert({
                       title: "我的邀请码",
                       //subTitle: '点击确定复制',
                       template: userKeyResponse.inviteCode,
                       okText: '确定',
                       cssClass: 'my-alert'
                   }).then(() => {
                       console.log('复制邀请码');
                   });
               }
               this.console.log('我的邀请码：',[JSON.stringify(userKeyResponse)]); // JSON.stringify(newReplyResponse.dataRows)
           }
        );

    }

    // 奖励说明
    // ---------------------------------
    award(){
        this.popup.alert({
            title: "奖励说明",
            template: this.index.benefit,
            okText: '确定',
            cssClass: 'my-alert'
        }).then(() => {
            console.log('查看奖励说明');
        });
    }

    // 每日签到
    // ---------------------------------
    sign(){
        let signData = {
            'uid': JSON.parse(localStorage.getItem('user')).uid,
            'token': JSON.parse(localStorage.getItem('user')).token,
            'starId': this.index.starId
        }
        this.http.server(JSON.parse(localStorage.getItem('todo')).star.sign, signData).subscribe(
            signResponse => {
                if(signResponse.flag && signResponse.isSuccess){
                    this.popup.alert({
                        title: "签到成功",
                        okText: '确定',
                        cssClass: 'my-alert'
                    }).then(() => {
                        console.log('每日签到成功');
                    });
                    this.http.server(JSON.parse(localStorage.getItem('todo')).star.added, this.addedStarData).subscribe(
                        addedStarResponse => {
                            this.stars = addedStarResponse.dataRows;
                            this.rowStyle = {
                                'width': (this.stars.length * 68) + 'px'
                            }
                            this.index = this.stars[0];
                            this.indexName = this.index.starName;
                            this.indexDistance = this.index.distance > 0 ? this.index.distance : 0;
                            //this.indexDistance = this.index.distance > 0 ? this.index.initialDistance - this.index.distance : this.index.initialDistance;
                            this.latestDistance = parseInt((this.indexDistance/this.index.initialDistance)*100);

                            //this.loader(this.index.initialDistance, this.index.distance > 0 ? this.index.distance : this.index.indexDistance);
                            this.console.log('已关注明星：',[JSON.stringify(addedStarResponse.dataRows)]); // JSON.stringify(newReplyResponse.dataRows)
                        }
                    );
                }else{
                    this.popup.alert({
                        title: signResponse.info,
                        okText: '确定',
                        cssClass: 'my-alert'
                    }).then(() => {
                        console.log('每日签到成功');
                    });
                }
                this.console.log('每日签到：',[JSON.stringify(signResponse)]); // JSON.stringify(newReplyResponse.dataRows)
            }
        );
    }

    // 初始化距离
    // ---------------------------------
    loader(initial,distance){
        this.runnerStyle = {
            'width' : Math.round(distance / initial * 100) + '%'
        }
        var Loader = function () {    
            var loader = document.querySelector('.loader-container'),
                meter = document.querySelector('.meter'),
                k, 
                i = Math.round(distance/initial,2),
                meter.innerHTML = '剩余 ' + i.toString();
                counter = function () {                                             
                        window.clearInterval(k);                    
                };

            return {
                init: function (options) {
                    options = options || {};
                    var time = options.time ? options.time : 0,
                          interval = time/100;
      
                    loader.classList.add('run');
                    k = window.setInterval(counter, interval); 
                    setTimeout(function () {        
                        loader.classList.add('done');
                    }, time);
                },
            }
        }();

        Loader.init({
            // 动态加载延时
            time: 3000
        });
    }

    onPageWillEnter(){
        this.http.server(JSON.parse(localStorage.getItem('todo')).star.added, this.addedStarData).subscribe(
                    addedStarResponse => {
                        this.stars = addedStarResponse.dataRows;
                        this.rowStyle = {
                            'width': (this.stars.length * 68) + 'px'
                        }
                        this.index = this.stars[0];
                        this.indexName = this.index.starName;
                        this.indexDistance = this.index.distance > 0 ? this.index.distance :0;
                        this.loader(this.index.initialDistance, this.index.distance > 0 ? this.index.distance : this.index.indexDistance);
                        this.console.log('已关注明星：',[JSON.stringify(addedStarResponse.dataRows)]); // JSON.stringify(newReplyResponse.dataRows)
                    }
                );

        this.http.server(JSON.parse(localStorage.getItem('todo')).user.info, this.userInfoData).subscribe(
           userInfoResponse => {
               //this.user = userInfoResponse.dataRows;
               this.console.log('个人信息：',[JSON.stringify(userInfoResponse)]); // JSON.stringify(newReplyResponse.dataRows)

               this.avatar = userInfoResponse.headPic;
               this.nickName = userInfoResponse.nickName;
               this.level = userInfoResponse.gamelevel;
               this.integral = userInfoResponse.integral;


           }
       );
    }

}
