﻿import {Page, Modal, IonicApp, NavController, Storage, LocalStorage, SqlStorage} from 'ionic/ionic';
import {Validators, Control, ControlGroup} from 'angular2/angular2';

import {StarterPage} from '../starter/starter';
import {PerfectPage} from '../../../base/app/perfect/perfect';
import {MainPage} from '../../../app/01.main/main';

import {HttpService} from '../../../units/http';
import {ConsoleService} from '../../../units/console';


@Page({
    templateUrl: 'base/app/login/login.html',
    providers: [ConsoleService]
})
export class LoginPage {
    constructor(app: IonicApp, nav: NavController, modal: Modal, http: HttpService, console: ConsoleService) {

        this.app = app;
        this.nav = nav;
        this.modal = modal;

        this.http = http;
        this.console = console;

        this.timing = '59';
        this.codeActivated = '';
        this.codeTips = '获取验证码';

        this.local = new Storage(LocalStorage);

        this.disabledCode = true;
        this.disabledLogin = true;

        this.form = new ControlGroup({
            tel: new Control('',Validators.required),
            code: new Control('',Validators.required)，
            key: new Control('',Validators.required)
        });

        this.prompt = '暂无提示';
        this.promptOpacity = 0.6;
        this.promptStyle = {
            'min-height':'0rem',
            'display':'none',
            'opacity': this.promptOpacity
        }

        this.demo = false;
        // 初始化登录
        // ---------------------------------
        this.modal.open(StarterPage,{ },{handle: 'starter-modal'});
    }


    // 输入校验：手机号
    // ---------------------------------
    telChecking(){
        if(this.form.value.code && this.form.value.code.length == '4' && !isNaN(this.form.value.code)){
            if(this.form.value.tel && this.form.value.tel.length == '11' && !isNaN(this.form.value.tel)){
                this.disabledLogin = false;
            }else{
                this.disabledLogin = true;
            }
        }else{
            if(this.form.value.tel && this.form.value.tel.length == '11' && !isNaN(this.form.value.tel) && this.timing == '59'){
                this.disabledCode = false;
                this.codeActivated = 'activated';
            }else{
                this.disabledCode = true;
                this.disabledLogin = true;
                this.codeActivated = '';
            }
        }
    }

    // 输入校验：验证码
    // ---------------------------------
    codeChecking(){
        if(this.form.value.tel && this.form.value.tel.length == '11' && !isNaN(this.form.value.tel) && this.form.value.code && this.form.value.code.length == '4'){
            this.disabledLogin = false;
        }else{
            this.disabledLogin = true;
        }
    }

    // 短信验证
    // ---------------------------------
    getCode(event){       
        this.disabledCode = true;

        let codeData = {
            'phoneNum': this.form.value.tel
        }
        this.http.server(JSON.parse(localStorage.getItem('todo')).user.code, codeData).subscribe(
            codeResponse => {
                this.console.log('短信验证',[JSON.stringify(codeResponse)]);
            },
            error => {
                this.prompt = '请求失败，请稍后再试！';
                this.promptStyle = {
                    'min-height':'0rem',
                    'display':'block',
                    'opacity': this.promptOpacity
                }
                setTimeout(() => {
                    let  timer = setInterval(() => {
                        if(this.promptOpacity <= 0){
                            clearInterval(timer);
                            this.promptOpacity = 0.6;
                            this.promptStyle = {
                                'min-height':'0rem',
                                'display':'none',
                                'opacity': this.promptOpacity
                            }
                        }else{
                            this.promptStyle = {
                                'min-height':'0rem',
                                'display':'block',
                                'opacity': this.promptOpacity
                            }
                            this.promptOpacity = this.promptOpacity - 0.02;
                        }
                    },50);
                },5000);
            }
        );

        timer = setInterval(() => {
            if(this.timing <= 1){
                clearInterval(timer);
                this.codeTips = '获取验证码';
                this.codeActivated = 'activated';
                this.disabledCode = false;
                this.timing = '59';
            }else{
                this.codeTips = this.timing + '秒可重发';
                this.timing --;
            }
        },1000);

        event.preventDefault();
    }

    // 首次登陆：进入首页
    // ---------------------------------
    login(event){

        // TODO-获取设备信息
        let registerData = {
            'phoneNum': this.form.value.tel,
            'validateCode': this.form.value.code,
            'deviceCode': '',
            'phoneModel': '',
            'phoneOs': '',
            'inviteCode': this.form.value.key
        }
        this.http.server(JSON.parse(localStorage.getItem('todo')).user.register, registerData).subscribe(
            registerResponse => {
                this.console.log('用户注册',[JSON.stringify(registerResponse)]);
                if(registerResponse.flag && registerResponse.isSuccess){
                    let loginData = {
                        'id': registerResponse.info,
                        'phoneNum': this.form.value.tel
                    }
                    this.http.server(JSON.parse(localStorage.getItem('todo')).user.login, loginData).subscribe(
                        loginResponse => {
                            this.console.log('首次登陆',[JSON.stringify(loginResponse)]);
                            if(loginResponse.flag && loginResponse.isSuccess){

                                // 初始化用户
                                // ---------------------------------
                                let user = {
                                    'uid': registerResponse.info,
                                    'tel': this.form.value.tel,
                                    'token': loginResponse.info
                                }
                                this.local.set('user',JSON.stringify(user));
                                if(localStorage.getItem('perfect')){
                                    this.nav.push(PerfectPage);
                                }else{
                                    
                                    this.nav.push(MainPage);
                                }
                            }else{
                                this.prompt = '登录失败，请稍后再试！';
                                this.promptStyle = {
                                    'min-height':'0rem',
                                    'display':'block',
                                    'opacity': this.promptOpacity
                                }
                                setTimeout(() => {
                                    let  timer = setInterval(() => {
                                        if(this.promptOpacity <= 0){
                                            clearInterval(timer);
                                            this.promptOpacity = 0.6;
                                            this.promptStyle = {
                                                'min-height':'0rem',
                                                'display':'none',
                                                'opacity': this.promptOpacity
                                            }
                                        }else{
                                            this.promptStyle = {
                                                'min-height':'0rem',
                                                'display':'block',
                                                'opacity': this.promptOpacity
                                            }
                                            this.promptOpacity = this.promptOpacity - 0.02;
                                        }
                                    },50);
                                },5000);
                            }
                        },
                        error => {
                            this.prompt = '请求失败，请稍后再试！';
                            this.promptStyle = {
                                'min-height':'0rem',
                                'display':'block',
                                'opacity': this.promptOpacity
                            }
                            setTimeout(() => {
                                let  timer = setInterval(() => {
                                    if(this.promptOpacity <= 0){
                                        clearInterval(timer);
                                        this.promptOpacity = 0.6;
                                        this.promptStyle = {
                                            'min-height':'0rem',
                                            'display':'none',
                                            'opacity': this.promptOpacity
                                        }
                                    }else{
                                        this.promptStyle = {
                                            'min-height':'0rem',
                                            'display':'block',
                                            'opacity': this.promptOpacity
                                        }
                                        this.promptOpacity = this.promptOpacity - 0.02;
                                    }
                                },50);
                            },5000);
                        }
                    );
                }else{
                    this.prompt = registerResponse.info == '验证码错误' ? '验证码错误，请重新输入！' : '注册失败，请稍后再试！';
                    this.promptStyle = {
                        'min-height':'0rem',
                        'display':'block',
                        'opacity': this.promptOpacity
                    }
                    setTimeout(() => {
                        let  timer = setInterval(() => {
                            if(this.promptOpacity <= 0){
                                clearInterval(timer);
                                this.promptOpacity = 0.6;
                                this.promptStyle = {
                                    'min-height':'0rem',
                                    'display':'none',
                                    'opacity': this.promptOpacity
                                }
                            }else{
                                this.promptStyle = {
                                    'min-height':'0rem',
                                    'display':'block',
                                    'opacity': this.promptOpacity
                                }
                                this.promptOpacity = this.promptOpacity - 0.02;
                            }
                        },50);
                    },5000);
                }
                
            },
            error => {
                this.prompt = '请求失败，请稍后再试！';
                this.promptStyle = {
                    'min-height':'0rem',
                    'display':'block',
                    'opacity': this.promptOpacity
                }
                setTimeout(() => {
                    let  timer = setInterval(() => {
                        if(this.promptOpacity <= 0){
                            clearInterval(timer);
                            this.promptOpacity = 0.6;
                            this.promptStyle = {
                                'min-height':'0rem',
                                'display':'none',
                                'opacity': this.promptOpacity
                            }
                        }else{
                            this.promptStyle = {
                                'min-height':'0rem',
                                'display':'block',
                                'opacity': this.promptOpacity
                            }
                            this.promptOpacity = this.promptOpacity - 0.02;
                        }
                    },50);
                },5000);
            }
        );

        event.preventDefault();
    }

    


    // 页面生命周期
    // ---------------------------------
    //onPageLoaded(){
    //    this.console.log('LoginPage',['onPageLoaded','页面加载完成！']);
    //}
    //onPageWillEnter(){
    //    this.console.log('LoginPage',['onPageWillEnter','页面即将激活！']);
    //}

    //onPageDidEnter(){
    //    this.console.log('LoginPage',['onPageDidEnter','页面已经激活！']);
    //}

    //onPageWillLeave (){
    //    this.console.log('LoginPage',['onPageWillLeave','页面即将退出！']);
    //}

    //onPageDidLeave() {
    //    this.console.log('LoginPage',['onPageDidLeave','页面已经退出！']);
    //}

    //onPageWillUnload (){
    //    this.console.log('LoginPage',['onPageWillUnload','页面即将销毁！']);
    //}

    //onPageDidUnload (){
    //    this.console.log('LoginPage',['onPageDidUnload','页面已经销毁！']);
    //}
}
