﻿import {Page, Platform, Popup, ActionSheet, NavController} from 'ionic/ionic';

import {HttpService} from '../../../units/http';
import {ConsoleService} from '../../../units/console';

@Page({
    templateUrl: 'base/user/profile/profile.html'
})
export class UserProfile {
    constructor(nav: NavController, platform: Platform, popup: Popup, actionSheet: ActionSheet, http: HttpService, console: ConsoleService) {

        this.http = http;
        this.popup = popup;
        this.platform = platform;
        this.actionSheet = actionSheet;
        this.console = console;
        // 初始化参数
        // ---------------------------------
        this.platform.is('android')? this.buttons = [
          { text: '拍照', icon: 'camera'},
          { text: '媒体库', icon: 'image' }
        ] : this.buttons = [
          { text: '拍照'},
          { text: '手机相册' }
        ]

        this.userInfoData = {
            'uid': JSON.parse(localStorage.getItem('user')).uid,
            'token': JSON.parse(localStorage.getItem('user')).token
        }

        this.http.server(JSON.parse(localStorage.getItem('todo')).user.info, this.userInfoData).subscribe(
            userInfoResponse => {
                //this.user = userInfoResponse.dataRows;
                this.console.log('个人信息：',[JSON.stringify(userInfoResponse)]); // JSON.stringify(newReplyResponse.dataRows)

                this.avatar = userInfoResponse.headPic;
                this.nickName = userInfoResponse.nickName;
                this.sexIndex = userInfoResponse.sex;
                this.sex = (userInfoResponse.sex == '1') ? '男' : '女';
                //this.tel = localStorage.getItem('tel');

            }
        );

        this.qiniuTokenData = {
            'uid': JSON.parse(localStorage.getItem('user')).uid,
            'token': JSON.parse(localStorage.getItem('user')).token,
            'bucket': JSON.parse(localStorage.getItem('post')).qiniu.user.host,
            'expires': JSON.parse(localStorage.getItem('post')).qiniu.expires
        }

        this.http.server(JSON.parse(localStorage.getItem('todo')).qiniu.token, this.qiniuTokenData).subscribe(
            qiniuTokenResponse => {
                this.qiniuToken = qiniuTokenResponse.uptoken;

            }
        );


    }

    changeHeadPic() {
        this.actionSheet.open({
            buttons: this.buttons,
            destructiveText: '',
            titleText: '上传头像',
            cancelText: '取消',
            cancel: () => {
                console.log('已取消！！');
            },
            destructiveButtonClicked: () => {
                // TODO-暂无删除
            },
            buttonClicked: (index) => {
                console.log('已选择：' + index);

                if (index == '0') { 
                    
                    navigator.camera.getPicture(
                        function (imageData) {
                            var image = document.getElementById('avatar');
                            image.src = "data:image/jpeg;base64," + imageData;
                            localStorage.setItem('userAvatar':imageData);
                            //this.avatar = 'data:image/jpeg;base64,' + imageData;
                        }, 
                       function (error) {

                       }, 
                       {
                           quality: 80,
                           destinationType: window.Camera.DestinationType.DATA_URL,
                           sourceType: window.Camera.PictureSourceType.CAMERA,
                           allowEdit: true,
                           encodingType: window.Camera.EncodingType.JPEG,
                           targetWidth: 400,
                           targetHeight: 400,
                           popoverOptions: window.CameraPopoverOptions,
                           saveToPhotoAlbum: false
                       });
                    this.actionSheetRef.close();
                }

                if(index == '1'){
                    navigator.camera.getPicture(
                            function (imageData) {
                                var image = document.getElementById('avatar');
                                image.src = "data:image/jpeg;base64," + imageData;
                                localStorage.setItem('userAvatar':imageData);
                                //this.avatar = 'data:image/jpeg;base64,' + imageData;
                            }, 
                           function (error) {

                           }, 
                           {
                               quality: 80,
                               destinationType: window.Camera.DestinationType.DATA_URL,
                               sourceType: window.Camera.PictureSourceType.SAVEDPHOTOALBUM,
                               allowEdit: true,
                               encodingType: window.Camera.EncodingType.JPEG,
                               targetWidth: 400,
                               targetHeight: 400,
                               popoverOptions: window.CameraPopoverOptions,
                               saveToPhotoAlbum: false
                           });
                    this.actionSheetRef.close();
                }
            }

        }).then(actionSheetRef => {
            this.actionSheetRef = actionSheetRef;
        });
    }

    changeNick(){
        this.popup.prompt({
            title: "更改昵称",
            template: "输入新昵称",
            inputPlaceholder: this.nickName,
            cancelText: '取消',
            okText: "更新"
        }).then((name) => {
            if(name != '' && name != this.nickName){
                let userTitleData = {
                    'uid': JSON.parse(localStorage.getItem('user')).uid,
                    'token': JSON.parse(localStorage.getItem('user')).token,
                    'nickName' : name
                }
                this.http.server(JSON.parse(localStorage.getItem('todo')).user.upTitle, userTitleData).subscribe(
                    data => {
                        console.log('更新昵称：' + JSON.stringify(data));
                        this.nickName = name;
                    }    
                );
            }
        }, () => {
            console.error('Prompt closed');
        });
    }

    changeSex(){
        this.actionSheet.open({
            buttons: [
              { text: '女' },
              { text: '男' }
            ],
            destructiveText: '',
            titleText: '更改性别',
            cancelText: '取消',
            cancel: () => {},
            destructiveButtonClicked: () => {},
            buttonClicked: (index) => {
                if(index == 0){
                    this.sex = '女';
                    this.actionSheetRef.close();
                }else{
                    this.sex = '男';
                    this.actionSheetRef.close();
                }
            }
        }).then(actionSheetRef => {
            // Action sheet was created and opened
            this.actionSheetRef = actionSheetRef;
            // this.actionSheetRef.close() to close it
        })
    }

    logOut(){
        localStorage.removeItem('user');
        location.reload();
    }

    onPageWillLeave (){
        if(localStorage.getItem('userAvatar') && localStorage.getItem('userAvatar') != ''){
            this.http.uploader(this.qiniuToken, localStorage.getItem('userAvatar')).subscribe(
                data => {
                    if(data.hash){
                        localStorage.removeItem('userAvatar');
                        let userAvatarData = {
                            'uid': JSON.parse(localStorage.getItem('user')).uid,
                            'token': JSON.parse(localStorage.getItem('user')).token,
                            'headPic' : JSON.parse(localStorage.getItem('post')).qiniu.user.http + data.key
                        }
                        this.http.server(JSON.parse(localStorage.getItem('todo')).user.upAvatar, userAvatarData).subscribe(
                            data => {
                                console.log('更新头像：' + JSON.stringify(data));
                            }    
                        );
                    }
                }
            );
            
        }

        this.newSex = this.sex == '男' ? 1 : 0;
        if(this.newSex != this.sexIndex){
            console.log('sex:'+ this.sex,'newSex:' + this.newSex);
            let userSexData = {
                'uid': JSON.parse(localStorage.getItem('user')).uid,
                'token': JSON.parse(localStorage.getItem('user')).token,
                'sex': this.newSex
            }
            this.http.server(JSON.parse(localStorage.getItem('todo')).user.upSex, userSexData).subscribe(
                data => {
                    console.log('更新昵称：' + JSON.stringify(data));
                }
            );
        }
        this.console.log('UserProfile',['onPageWillLeave','页面即将退出！']);
    }
}
